Struct unicode_names::Name [] [src]

pub struct Name {
    // some fields omitted
}

An iterator over the components of a code point's name, it also implements Show.

The size hint is exact for the number of pieces, but iterates (although iteration is cheap and all names are short).

Methods

impl Name

fn len(&self) -> usize

The number of bytes in the name.

All names are plain ASCII, so this is also the number of Unicode codepoints and the number of graphemes.